@@ -59,7 +59,7 @@ def check_meta_file_parsing(app, reporter):
             reporter.fail(reporter_output, file_path, line)
 
 
-@splunk_appinspect.tags("cloud", "private_app", "future")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic", "future")
 def check_kos_are_accessible(app, reporter):
     """Check that knowledge objects with access control restrictions defined in
      *.meta files are accessible to customers in Splunk Cloud."""
