@@ -121,7 +121,14 @@ def check_user_privileges(app, reporter):
         reporter.manual_check(reporter_output, filepath, line_number)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "private_app",
+    "private_victoria",
+    "private_classic"
+)
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_destructive_commands(app, reporter):
     """Check for the use of malicious shell commands in configuration files or shell scripts to
