@@ -393,7 +393,7 @@ def check_props_conf_regex_stanza_name_followed_by_double_colon(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
     """
