@@ -97,7 +97,7 @@ def check_for_secret_disclosure(app, reporter):
             continue
         if _secret_disclosure_values_whitelist(result):
             continue
-        if _conf_options_secret_disclosure_whitelist(file_path, result):
+        if _secret_disclosure_values_savedsearches_allowlist(file_path, result):
             continue
         reporter_output = (
             "The following line will be inspected during code review."
@@ -161,13 +161,33 @@ def _secret_disclosure_values_whitelist(line_message):
         r"((?i)((?:(key|pass|pwd|token|login|passwd|password|community|privpass))[ ]{0,10}=[ ]{0,10}((<|\"|\'|\\\"|\\\')?(%s)(>|\"|\'|\\\"|\\\')?)$))"
         % ("|".join(values_whitelist))
     )
-
     if re.search(values_patterns, line_message):
         return True
 
+    key_value_set = {
+        'change_own_password': '(enabled|disabled)',
+    }
+    for key, value in key_value_set.items():
+        if re.match(rf"\s*{key}\s*=\s*((<|\"|\'|\\\"|\\\')?{value}(>|\"|\'|\\\"|\\\')?)\s*", line_message):
+            return True
+
     return False
 
 
+def _secret_disclosure_values_savedsearches_allowlist(file_path, line_message):
+    savedsearches_files = [
+        os.path.join("default", "savedsearches.conf"),
+        os.path.join("local", "savedsearches.conf")
+    ]
+    if file_path not in savedsearches_files:
+        return False
+
+    if re.match(r"\s*(alert.[\w-]+.params.[\w-]+)\s*=\s*((<|\"|\'|\\\"|\\\')?([\w]+)(>|\"|\'|\\\"|\\\')?)\s*", line_message):
+        return False
+
+    return True
+
+
 def _conf_options_secret_disclosure_whitelist(file_path, line_message):
     """Checks if the line message matched by the secret disclosure regex
     is a whitelisted configuration option.
@@ -441,7 +461,7 @@ def check_symlink_outside_app(app, reporter):
                     reporter.fail(reporter_output, app_file_path)
 
 
-@splunk_appinspect.tags("cloud", "private_app", "splunk_9_0", "future", "private_victoria", "private_classic", "pura")
+@splunk_appinspect.tags("cloud", "private_app", "splunk_9_0", "private_victoria", "private_classic", "pura")
 def check_for_supported_tls(app, reporter):
     """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
     client = app.python_analyzer_client
@@ -468,7 +488,7 @@ def check_for_supported_tls(app, reporter):
                     f"make sure you bundle your own CA certs as part of your app and pass the path "
                     f"into {lib_name} as an arg."
                 )
-                reporter.warn(reporter_output, file_path, usage.lineno)
+                reporter.fail(reporter_output, file_path, usage.lineno)
 
     for file_path, ast_info in client.get_all_ast_infos():
         _report_if_all_kwrgs_found(
