@@ -128,33 +128,6 @@ def check_setup_in_distributed_environment(app, reporter):
             reporter_output = f"Custom setup page {custom_setup_name} is not found in default/data/ui. File: {file_path}"
             reporter.fail(reporter_output, file_path)
 
-
-@splunk_appinspect.tags("self-service")
-@splunk_appinspect.cert_version(min="1.6.1")
-def check_that_json_schema_is_applicable(app, reporter):
-    """If json schema is 2.0.0 in app.manifest then warn it.
-    Because schema version of 2.0.0 is not yet compatible with any versions
-    of the Splunk Cloud. So far, all cloud stack are 7.0 and lower but
-    Json Schema 2.0.0 is only compatible with Splunk 7.1+.
-    """
-    if not app.package.does_working_artifact_contain_app_manifest():
-        reporter.not_applicable("app.manifest does not exist.")
-        return
-    app_manifest_path = os.path.join(app.package.working_app_path, "app.manifest")
-    try:
-        schema_version = _extract_json_schema(app_manifest_path)
-    except ValueError as error:
-        reporter.fail(f"Malformed app.manifest file. Json loading error: {str(error)}")
-        return
-    if schema_version != "1.0.0":
-        reporter_output = (
-            "Json Schema version of 2.0.0 is not yet compatible with any versions of the Splunk Cloud (7.0 and lower)"
-            " so the app can't be SSAI. http://dev.splunk.com/view/packaging-toolkit/SP-CAAAE96#older"
-            " File: app.manifest"
-        )
-        reporter.warn(reporter_output)
-
-
 def _extract_json_schema(file_path):
     with open(file_path) as f:
         content = f.read()
