@@ -107,6 +107,9 @@ class ConfigurationFile(object):
             sectionname
         ).has_option(key)
 
+    def get_option(self, sectionname, key):
+        return self.get_section(sectionname).get_option(key)
+
     def has_section(self, sectionname):
         return sectionname in self.sects
 
