@@ -2,8 +2,12 @@
 interfaces that are unique to the Unix operating system, or in some cases to some or many variants of it.
 """
 
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.UNIX_SPECIFIX_SERVICES)
@@ -13,6 +17,7 @@ def fork():
     """
     pass
 
+
 @tags(TagConsts.UNIX_SPECIFIX_SERVICES)
 def openpty():
     """
@@ -20,9 +25,10 @@ def openpty():
     """
     pass
 
+
 @tags(TagConsts.UNIX_SPECIFIX_SERVICES)
 def spawn():
     """
     Spawn a process
     """
-    pass
\ No newline at end of file
+    pass
